@@ -1,9 +1,9 @@
-from office365.runtime.auth.UserCredential import UserCredential
-from office365.sharepoint.client_context import ClientContext
 from settings import settings
 
+from office365.runtime.auth.user_credential import UserCredential
+from office365.sharepoint.client_context import ClientContext
 
-ctx = ClientContext.connect_with_credentials("https://mediadev8.sharepoint.com/sites/team/",
+ctx = ClientContext(settings["url"]).with_credentials(
                                              UserCredential(settings['user_credentials']['username'],
                                                             settings['user_credentials']['password']))
 
@@ -11,5 +11,3 @@ web = ctx.web
 ctx.load(web)
 ctx.execute_query()
 print(web.properties["Url"])
-
-
