@@ -1,10 +1,9 @@
-from office365.runtime.client_value_object import ClientValueObject
+from office365.runtime.client_value import ClientValue
 
 
-class TeamFunSettings(ClientValueObject):
+class TeamFunSettings(ClientValue):
     """Settings to configure use of Giphy, memes, and stickers in the team."""
 
     def __init__(self):
         super().__init__()
         self.allowGiphy = True
-
