@@ -1,5 +1,5 @@
-from office365.runtime.client_result import ClientResult
 from office365.runtime.client_object import ClientObject
+from office365.runtime.client_result import ClientResult
 from office365.runtime.http.request_options import RequestOptions
 from office365.runtime.types.EventHandler import EventHandler
 
@@ -9,7 +9,7 @@ class ClientObjectCollection(ClientObject):
     def __init__(self, context, item_type, resource_path=None):
         """Client object collection
 
-        :type context: ClientRuntimeContext
+        :type context: office365.runtime.client_runtime_context.ClientRuntimeContext
         :type item_type: type[ClientObject]
         :type resource_path: ResourcePath
         """
@@ -52,6 +52,9 @@ class ClientObjectCollection(ClientObject):
         self._data.remove(client_object)
 
     def __iter__(self):
+        """
+        :rtype: collections.Iterable[ClientObject]
+        """
         for cur_item in self._data:
             yield cur_item
 
@@ -103,12 +106,12 @@ class ClientObjectCollection(ClientObject):
         :return: ClientResult
         """
         result = ClientResult(None)
-        self.context.load(self)
 
-        def _calc_items_count(target_collection):
-            list(iter(target_collection))
-            result.value = len(target_collection)
-        self.context.afterExecuteOnce += _calc_items_count
+        def _calc_items_count(resp):
+            list(iter(self))
+            result.value = len(self)
+        self.context.load(self)
+        self.context.after_execute(_calc_items_count)
         return result
 
     def _load_paged_items(self):
