@@ -1,6 +1,8 @@
 from abc import abstractmethod
+
 import requests
 from requests import HTTPError
+
 from office365.runtime.client_request_exception import ClientRequestException
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.types.EventHandler import EventHandler
@@ -19,10 +21,34 @@ class ClientRequest(object):
         self.beforeExecute = EventHandler()
         self.afterExecute = EventHandler()
 
+    def __iter__(self):
+        while self._queries:
+            qry = self._queries.pop(0)
+            yield qry
+
+    def __len__(self):
+        return len(self._queries)
+
+    def __getitem__(self, index):
+        return self._queries[index]
+
     @property
     def queries(self):
+        """
+        :rtype: list[ClientQuery]
+        """
         return self._queries
 
+    def add_query(self, query, to_begin=False):
+        """
+        :type to_begin: bool
+        :type query: ClientQuery
+        """
+        if to_begin:
+            self._queries.insert(0, query)
+        else:
+            self._queries.append(query)
+
     @abstractmethod
     def build_request(self):
         pass
@@ -87,10 +113,3 @@ class ClientRequest(object):
                                   stream=request_options.stream,
                                   proxies=request_options.proxies)
         return result
-
-    def add_query(self, query):
-        """
-        :type query: ClientQuery
-
-        """
-        self._queries.append(query)
