@@ -1,49 +1,55 @@
 from office365.runtime.client_object import ClientObject
 from office365.runtime.client_object_collection import ClientObjectCollection
-from office365.runtime.client_query import CreateEntityQuery, UpdateEntityQuery, DeleteEntityQuery
+from office365.runtime.client_query import CreateEntityQuery, DeleteEntityQuery, UpdateEntityQuery
 from office365.runtime.client_request import ClientRequest
 from office365.runtime.client_result import ClientResult
-from office365.runtime.client_value_object import ClientValueObject
+from office365.runtime.client_value import ClientValue
+from office365.runtime.client_value_collection import ClientValueCollection
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.http.request_options import RequestOptions
 from office365.runtime.odata.json_light_format import JsonLightFormat
 from office365.runtime.odata.odata_metadata_level import ODataMetadataLevel
-from office365.runtime.serviceOperationQuery import ServiceOperationQuery
+from office365.runtime.queries.service_operation_query import ServiceOperationQuery
 
 
 class ODataRequest(ClientRequest):
 
     def __init__(self, context, json_format):
+        """
+
+        :type context: office365.runtime.client_runtime_context.ClientRuntimeContext
+        :type json_format: office365.runtime.odata.odata_json_format.ODataJsonFormat
+        """
         super(ODataRequest, self).__init__(context)
         self._json_format = json_format
-        self._current_query = None
-
-    def execute_request_direct(self, request):
-        media_type = self.json_format.get_media_type()
-        request.ensure_header('Content-Type', media_type)
-        request.ensure_header('Accept', media_type)
-        return super(ODataRequest, self).execute_request_direct(request)
-
-    @property
-    def current_query(self):
-        return self._current_query
 
     @property
     def json_format(self):
         return self._json_format
 
-    def _get_next_query(self):
-        self._current_query = self._queries.pop(0)
-        return self._current_query
+    def execute_request_direct(self, request):
+        """
+        Executes request directly
+
+        :param RequestOptions request: request
+        :return: requests.Response
+        """
+        self.ensure_media_type(request)
+        return super(ODataRequest, self).execute_request_direct(request)
+
+    def ensure_media_type(self, request):
+        media_type = self.json_format.get_media_type()
+        request.ensure_header('Content-Type', media_type)
+        request.ensure_header('Accept', media_type)
 
     def build_request(self):
-        qry = self._get_next_query()
+        qry = self.context.current_query
         self.json_format.function_tag_name = None
-
         if isinstance(qry, ServiceOperationQuery):
             self.json_format.function_tag_name = qry.method_name
             if qry.static:
-                request_url = self.context.service_root_url + '.'.join([qry.binding_type.entity_type_name, qry.method_url])
+                request_url = self.context.service_root_url + '.'.join(
+                    [qry.binding_type.entity_type_name, qry.method_url])
             else:
                 request_url = '/'.join([qry.binding_type.resource_url, qry.method_url])
         else:
@@ -54,16 +60,18 @@ class ODataRequest(ClientRequest):
         request.method = HttpMethod.Get
         if isinstance(qry, DeleteEntityQuery):
             request.method = HttpMethod.Post
-        elif isinstance(qry, CreateEntityQuery) \
-            or isinstance(qry, UpdateEntityQuery) \
-            or isinstance(qry, ServiceOperationQuery):
+        elif isinstance(qry, (CreateEntityQuery, UpdateEntityQuery, ServiceOperationQuery)):
             request.method = HttpMethod.Post
             if qry.parameter_type is not None:
                 request.data = self._normalize_payload(qry.parameter_type)
         return request
 
     def process_response(self, response):
-        result_object = self._current_query.return_type
+        """
+        :type response: requests.Response
+        """
+        qry = self.context.current_query
+        result_object = qry.return_type
         if isinstance(result_object, ClientObjectCollection):
             result_object.clear()
 
@@ -115,7 +123,15 @@ class ODataRequest(ClientRequest):
                         yield name, value
 
     def _normalize_payload(self, value):
-        if isinstance(value, ClientObject) or isinstance(value, ClientValueObject):
+        """
+        :type value: ClientValue or ClientResult  or ClientObject
+        """
+        qry = self.context.current_query
+        if isinstance(value, ClientValueCollection):
+            if isinstance(self._json_format,
+                          JsonLightFormat) and self._json_format.metadata == ODataMetadataLevel.Verbose:
+                value = {"results": value.to_json()}
+        elif isinstance(value, ClientObject) or isinstance(value, ClientValue):
             json = value.to_json()
             for k, v in json.items():
                 json[k] = self._normalize_payload(v)
@@ -124,8 +140,9 @@ class ODataRequest(ClientRequest):
                           JsonLightFormat) and self._json_format.metadata == ODataMetadataLevel.Verbose:
                 json[self._json_format.metadata_type_tag_name] = {'type': value.entity_type_name}
 
-            if isinstance(self._current_query, ServiceOperationQuery) and self._current_query.parameter_name is not None:
-                json = {self._current_query.parameter_name: json}
+            if isinstance(qry,
+                          ServiceOperationQuery) and qry.parameter_name is not None:
+                json = {qry.parameter_name: json}
             return json
         elif isinstance(value, dict):
             for k, v in value.items():
