@@ -1,8 +1,8 @@
 from office365.runtime.client_object import ClientObject
 from office365.runtime.client_result import ClientResult
+from office365.runtime.queries.service_operation_query import ServiceOperationQuery
 from office365.runtime.resource_path import ResourcePath
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
-from office365.runtime.queries.serviceOperationQuery import ServiceOperationQuery
 from office365.sharepoint.lists.list import List
 from office365.sharepoint.principal.user import User
 from office365.sharepoint.webs.web import Web
