@@ -1,11 +1,12 @@
 import uuid
 
-from office365.sharepoint.fields.field import Field
-from office365.sharepoint.fields.fieldText import FieldText
-from office365.sharepoint.fields.fieldType import FieldType
-from office365.sharepoint.fields.field_creation_information import FieldCreationInformation
 from tests.sharepoint.sharepoint_case import SPTestCase
 
+from office365.sharepoint.fields.field import Field
+from office365.sharepoint.fields.field_creation_information import FieldCreationInformation
+from office365.sharepoint.fields.field_text import FieldText
+from office365.sharepoint.fields.field_type import FieldType
+
 
 class TestField(SPTestCase):
     target_field = None   # type: Field
@@ -21,8 +22,8 @@ class TestField(SPTestCase):
         title_field = self.client.site.rootWeb.fields.get_by_internal_name_or_title(self.target_field_name)
         self.client.load(title_field)
         self.client.execute_query()
-        self.assertIsNotNone(title_field.properties['InternalName'])
-        self.assertEqual(title_field.properties['InternalName'], self.target_field_name)
+        self.assertIsNotNone(title_field.internal_name)
+        self.assertEqual(title_field.internal_name, self.target_field_name)
         self.assertIsInstance(title_field, FieldText)
         self.assertIsNotNone(title_field.max_length)
 
@@ -30,8 +31,8 @@ class TestField(SPTestCase):
         title_field = self.client.site.rootWeb.fields.get_by_title(self.target_field_name)
         self.client.load(title_field)
         self.client.execute_query()
-        self.assertIsNotNone(title_field.properties['InternalName'])
-        self.assertEqual(title_field.properties['InternalName'], self.target_field_name)
+        self.assertIsNotNone(title_field.internal_name)
+        self.assertEqual(title_field.internal_name, self.target_field_name)
 
     def test_4_create_site_field(self):
         field_name = "Title_" + uuid.uuid4().hex
